@@ -12,8 +12,10 @@ class App(Base):
     self._options = Helper.opt_parser()
 
     if(self._options["command"] == "info"):
-      self._info_file = open(self._options["file"], "w+")
-      Helper.write_hash_to_file({"language":"python", "name":self._name, "flow_type":"app", "multilang_version":VERSION}, self._info_file)
+      sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+      sock.connect((self._options["host"], int(self._options["port"])))
+      self._socket = sock.makefile()
+      Helper.write_hash_to_file({"language":"python", "name":self._name, "flow_type":"app", "multilang_version":VERSION}, self._socket)
 
   def source(self, name=None, matches=None, options={}, emits=None, end_cycle_policy="null_emit", begin_cycle=None, next_tuple=None):
     op = OperationHandler(self, Stream)
