@@ -26,23 +26,26 @@ class Filter:
     Helper.check_emits("filter", self._emits, self._app._streams)
 
   def run_operation(self):
-    pipe_name = self._app._options.get("pipe","")
-    controller = Controller(pipe_name, self._emits)
+    host = self._app._options.get("host", None)
+    port = self._app._options.get("port", None)
+    controller = Controller(host, port, self._emits)
 
     controller.get_pidDir()
-    if self._prepare != None:
-      self._prepare(controller)
 
     while True:
       try:
         d = controller.read()
         if d == None:
           continue
-        tup = controller.get_tuple(d)
-        if tup == None:
-          continue
-        if self._keep(tup):
-          controller.emit(tup)
+        elif "command" in d and d["command"] == "prepare":
+          if self._prepare != None:
+            self._prepare(controller)
+        else:
+          tup = controller.get_tuple(d)
+          if tup == None:
+            continue
+          if self._keep(tup):
+            controller.emit(tup)
       except KeyboardInterrupt:
         raise
       except ParentDeadException, e:
