@@ -28,8 +28,9 @@ class GroupBy:
     Helper.check_emits("group_by", self._emits, self._app._streams)
 
   def run_operation(self):
-    pipe_name = self._app._options.get("pipe","")
-    controller = Controller(pipe_name, self._emits)
+    host = self._app._options.get("host", None)
+    port = self._app._options.get("port", None)
+    controller = Controller(host, port, self._emits)
 
     controller.get_pidDir()
 
@@ -40,6 +41,9 @@ class GroupBy:
           continue
         elif "command" not in d:
           controller.log("Not a command "+str(d))
+        elif d["command"] == "prepare":
+          if self._prepare != None:
+            self._prepare(controller)
         elif d["command"] == "begin_group":
           tup = controller.get_tuple(d)
           if tup == None:
