@@ -7,6 +7,7 @@ class Helper:
   META_NAMES = ["id", "confidence", "since", "source"]
   ALLOWED_END_CYCLE_POLICIES= ["null_emit", "explicit"]
   ALLOWED_OUTPUT_FORMATS = ["replace", "merge"]
+  ALLOWED_TYPES = ["string", "integer", "float", "double", "boolean", "array", "map"]
  
   argv = sys.argv[1:]
   @classmethod
@@ -26,12 +27,12 @@ class Helper:
       elif arg == "--name":
         i += 1
         options["name"] = self.argv[i]
-      elif arg == "--pipe":
+      elif arg == "--host":
         i += 1
-        options["pipe"] = self.argv[i]
-      elif arg == "--file":
+        options["host"] = self.argv[i]
+      elif arg == "--port":
         i += 1
-        options["file"] = self.argv[i]
+        options["port"] = self.argv[i]
       i += 1
     return options
   
@@ -43,6 +44,7 @@ class Helper:
   @classmethod
   def write_hash_to_file(self, h, f):
     f.write(json.dumps(h)+"\n")
+    f.flush()
 
   @classmethod
   def write_node_to_file(self, h, f):
@@ -277,7 +279,7 @@ class Helper:
       if not isinstance(colval, basestring) or colval == "":
         msg = ee+"Field data types must be non-empty STRINGS in \"%s\"."%(name)+pp
         self.print_error(msg)
-      if colval != "float" and colval != "double" and colval != "string" and colval != "integer" and colval != "boolean":
+      if colval not in self.ALLOWED_TYPES:
         msg = ee+"Invalid field data type at \"%s\" in \"%s\"."%(colval,name)+pp
         self.print_error(msg)
 
@@ -295,6 +297,21 @@ class Helper:
 
     self.check_field_format("outputs", pp, node._name, node._columns)
 
+  @classmethod
+  def check_loop_back(self, node_name, nodes):
+    ee = "Error in \"loop_back\": \n\t "
+
+    found = False
+    for node in nodes:
+      if node._name == node_name:
+        found = True
+        if node._type == "source":
+          msg = ee+"Cannot loop back to source node \"%s\"!"%(node_name)
+          self.print_error(msg)
+    if not found:
+      msg = ee+"The specified loop-back node \"%s\" was not found in the operations preceding it."%(node_name)
+      self.print_error(msg)
+
   print_check_source = """\n
 "Source" Syntax:
   Sourcing from a relation:
@@ -369,7 +386,7 @@ class Helper:
   - "Columns" must be a non-empty LIST.
   - Field names must be non-empty STRINGS with only alphanumeric or underscore characters.
   - Field names cannot be "v[number]", "id", "confidence", "since" or "source" which are reserved Zillabyte names.
-  - Field types may be "string", "integer", "float", "double", or "boolean"."""
+  - Field types may be "string", "integer", "float", "double", "boolean", "array" or "map"."""
   
   print_check_component_sink = """\n
 "Outputs" Syntax:
@@ -379,7 +396,7 @@ class Helper:
   - "Columns" must be a non-empty LIST.
   - Field names must be non-empty STRINGS with only alphanumeric or underscore characters.
   - Field names cannot be "v[number]", "id", "confidence", "since" or "source" which are reserved Zillabyte names.
-  - Field types may be "string", "integer", "float", "double", or "boolean"."""
+  - Field types may be "string", "integer", "float", "double", "boolean", "array" or "map"."""
 
   print_check_component_source = """\n
 "Inputs" Syntax:
@@ -389,7 +406,7 @@ class Helper:
   - "Fields" must be a non-empty LIST.
   - Field names must be non-empty STRINGS with only alphanumeric or underscore characters.
   - Field names cannot be "v[number]", "id", "confidence", "since" or "source" which are reserved Zillabyte names.
-  - Field types may be "string", "integer", "float", "double", or "boolean"."""
+  - Field types may be "string", "integer", "float", "double", "boolean", "array" or "map"."""
   
   print_check_component_sink = """\n
 "Outputs" Syntax:
@@ -399,7 +416,7 @@ class Helper:
   - "Fields" must be a non-empty LIST.
   - Field names must be non-empty STRINGS with only alphanumeric or underscore characters.
   - Field names cannot be "v[number]", "id", "confidence", "since" or "source" which are reserved Zillabyte names.
-  - Field types may be "string", "integer", "float", "double", or "boolean"."""
+  - Field types may be "string", "integer", "float", "double", "boolean", "array" or "map"."""
 
   print_check_call_component = """\n
 "Call_component" Syntax:
