@@ -8,8 +8,8 @@ class Join:
   def build_node(self, name, lhs_stream, rhs_stream, emits, fields, options):
     self._name = name if name else "join_"+Counter.get()
     self._type = "join"
-    self._lhs_stream = lhs_stream
-    self._rhs_stream = rhs_stream
+    self._lhs_stream = lhs_stream._name
+    self._rhs_stream = rhs_stream._name
 
     if emits == None:
       emits = ["stream_"+Counter.get()]
